summary refs log tree commit diff
path: root/pkgs/development/embedded
diff options
context:
space:
mode:
authorAtemu <atemu.main@gmail.com>2023-04-11 12:52:27 +0200
committerAtemu <atemu.main@gmail.com>2023-04-16 10:15:13 +0200
commitf63a12f296b806a1b838d6fd8eef99fa65929649 (patch)
treebf9627db4a9a4a265dfccfef4e43338606d9c3e5 /pkgs/development/embedded
parent1baab4e14a6c9d5fd0f3e6af144aeeb61e911110 (diff)
downloadnixpkgs-f63a12f296b806a1b838d6fd8eef99fa65929649.tar
nixpkgs-f63a12f296b806a1b838d6fd8eef99fa65929649.tar.gz
nixpkgs-f63a12f296b806a1b838d6fd8eef99fa65929649.tar.bz2
nixpkgs-f63a12f296b806a1b838d6fd8eef99fa65929649.tar.lz
nixpkgs-f63a12f296b806a1b838d6fd8eef99fa65929649.tar.xz
nixpkgs-f63a12f296b806a1b838d6fd8eef99fa65929649.tar.zst
nixpkgs-f63a12f296b806a1b838d6fd8eef99fa65929649.zip
tree-wide: buildFHSUserEnv -> buildFHSEnv
Diffstat (limited to 'pkgs/development/embedded')
-rw-r--r--pkgs/development/embedded/arduino/arduino-cli/default.nix6
-rw-r--r--pkgs/development/embedded/arduino/arduino-core/chrootenv.nix4
-rw-r--r--pkgs/development/embedded/platformio/chrootenv.nix4
3 files changed, 7 insertions, 7 deletions
diff --git a/pkgs/development/embedded/arduino/arduino-core/chrootenv.nix b/pkgs/development/embedded/arduino/arduino-core/chrootenv.nix
index 4c13b2493a9..1313a9aeada 100644
--- a/pkgs/development/embedded/arduino/arduino-core/chrootenv.nix
+++ b/pkgs/development/embedded/arduino/arduino-core/chrootenv.nix
@@ -1,8 +1,8 @@
-{ lib, buildFHSUserEnv, arduino-core-unwrapped, withGui ? false, withTeensyduino ? false }:
+{ lib, buildFHSEnv, arduino-core-unwrapped, withGui ? false, withTeensyduino ? false }:
 let
   arduino-unwrapped = arduino-core-unwrapped.override { inherit withGui withTeensyduino; };
 in
-buildFHSUserEnv {
+buildFHSEnv {
   name = "arduino";
 
   targetPkgs =
diff --git a/pkgs/development/embedded/platformio/chrootenv.nix b/pkgs/development/embedded/platformio/chrootenv.nix
index dd3da78250a..55adb0edaa7 100644
--- a/pkgs/development/embedded/platformio/chrootenv.nix
+++ b/pkgs/development/embedded/platformio/chrootenv.nix
@@ -1,4 +1,4 @@
-{ lib, buildFHSUserEnv, platformio-core }:
+{ lib, buildFHSEnv, platformio-core }:
 
 let
   pio-pkgs = pkgs:
@@ -19,7 +19,7 @@ let
     ]);
 
 in
-buildFHSUserEnv {
+buildFHSEnv {
   name = "platformio";
 
   targetPkgs = pio-pkgs;
diff --git a/pkgs/development/embedded/arduino/arduino-cli/default.nix b/pkgs/development/embedded/arduino/arduino-cli/default.nix
index a23bf5d433b..68e4b7413a3 100644
--- a/pkgs/development/embedded/arduino/arduino-cli/default.nix
+++ b/pkgs/development/embedded/arduino/arduino-cli/default.nix
@@ -1,4 +1,4 @@
-{ lib, stdenv, buildGoModule, fetchFromGitHub, buildFHSUserEnv, installShellFiles }:
+{ lib, stdenv, buildGoModule, fetchFromGitHub, buildFHSEnv, installShellFiles }:
 
 let
 
@@ -48,10 +48,10 @@ let
 
 in
 if stdenv.isLinux then
 # buildFHSUserEnv is needed because the arduino-cli downloads compiler
 # toolchains from the internet that have their interpreters pointed at
 # /lib64/ld-linux-x86-64.so.2
-  buildFHSUserEnv
+  buildFHSEnv
   {
     inherit (pkg) name meta;
 
@@ -48,10 +48,10 @@ let
 in
 if stdenv.isLinux then
-# buildFHSUserEnv is needed because the arduino-cli downloads compiler
+# buildFHSEnv is needed because the arduino-cli downloads compiler
 # toolchains from the internet that have their interpreters pointed at
 # /lib64/ld-linux-x86-64.so.2